function [X1,X2,X3] = comptraj(x,mom,T,sigmaV2)

% computes trajectories given momentum mom and initial positions x
%
% author : Joan Glaunès - joan.glaunes@free.fr

tau = 1/(T-1);
nx = size(mom,1);

mom1 = mom(:,:,1);
mom2 = mom(:,:,2);
mom3 = mom(:,:,3);

X1 = zeros(nx,T);
X2 = zeros(nx,T);
X3 = zeros(nx,T);
X1(:,1) = x(1,:)';
X2(:,1) = x(2,:)';
X3(:,1) = x(3,:)';

% compute trajectories
for t = 1:T-1
    for k = (t-1)*nx+1:t*nx
        dX1 = 0;
        dX2 = 0;
        dX3 = 0;
        for l = (t-1)*nx+1:t*nx
            arg = -( ...
                (X1(k)-X1(l))^2 + ...
                (X2(k)-X2(l))^2 + ...
                (X3(k)-X3(l))^2)/sigmaV2(t);
arg = 1/(1-arg);  %% BUILT IN KERNEL kerV, do not remove this comment
            dX1 = dX1 + arg * mom1(l);
            dX2 = dX2 + arg * mom2(l);
            dX3 = dX3 + arg * mom3(l);
        end
        X1(k+nx) = X1(k) + tau * dX1;
        X2(k+nx) = X2(k) + tau * dX2;
        X3(k+nx) = X3(k) + tau * dX3;
    end
end
