function s = setparams(s)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%% Parameters for measmatch algorithm %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% author : Joan Glaunès - joan.glaunes@free.fr


% x (template) and y (target) are required components
if ~isfield(s,'x') | ~isfield(s,'y')
    error('input structure must contain at least fields x (template) and y (target)');
end

% x and y must be 3D data
if size(s.x,1)~=3 | size(s.y,1)~=3
    error('fields x and y must be 3-rows matrices');
end

nx = size(s.x,2);         % number of template points
ny = size(s.y,2);         % number of target points

T = 30;                     % time discretization

% groups labels: for each point, specify number of group starting from 1
grpx = ones(1,nx);          % group labels for template points
grpy = ones(1,ny);          % group labels for target points

% weights of points: specify either for each point or for each group
wx = ones(1,nx);            % weights of template points
wy = ones(1,ny);            % weights of target points
equalweights = 1;           % if 1 then normalize weights

sigmaV = 'auto';            % deformation kernel size 
sigmaI = 'auto';            % matching kernel size 
gammaR = 'auto';            % balance between deformation and matching 

transmatrix = eye(3);       % additional affine transformation
transvector = zeros(3,1);   % additional affine transformation
resetmode = 1;              % if 1 then reset trajectories and moments

useoptim = 'adaptdesc';      % optimization method ('fixedesc', 'adaptdesc' or 'conjgrad')
optim_maxiter = 500;     % maximum number of iterations
optim_stepsize = 'auto';    % gradient descent step
optim_breakratio = 1e-6;    % ratio for termination criteria
optim_verbosemode = 0;    % if 1 display text information while processing

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% update by parameters provided by structure s
loadstruct('s');
clear s

% save all variables in structure s
savestruct('s',who);
